==> monaco-vscode-api-4.1.0.tgz: package/vscode/src/vs/workbench/services/preferences/browser/keybindingsEditorInput.js <==
import { __decorate, __param } from '../../../../../../../external/tslib/tslib.es6.js';
import { Codicon } from '../../../../base/common/codicons.js';
import { OS } from '../../../../base/common/platform.js';
import { localizeWithPath } from '../../../../nls.js';
import { IInstantiationService } from '../../../../platform/instantiation/common/instantiation.js';
import { registerIcon } from '../../../../platform/theme/common/iconRegistry.js';
import { EditorInput } from '../../../common/editor/editorInput.js';
import { KeybindingsEditorModel } from './keybindingsEditorModel.js';
var KeybindingsEditorInput_1;
const KeybindingsEditorIcon = registerIcon('keybindings-editor-label-icon', Codicon.keyboard, ( localizeWithPath(
    'vs/workbench/services/preferences/browser/keybindingsEditorInput',
    'keybindingsEditorLabelIcon',
    'Icon of the keybindings editor label.'
)));
let KeybindingsEditorInput = class KeybindingsEditorInput extends EditorInput {
    static { KeybindingsEditorInput_1 = this; }
    static { this.ID = 'workbench.input.keybindings'; }
    constructor(instantiationService) {
        super();
        this.searchOptions = null;
        this.resource = undefined;
        this.keybindingsModel = instantiationService.createInstance(KeybindingsEditorModel, OS);
    }
    get typeId() {
        return KeybindingsEditorInput_1.ID;
    }
    getName() {
        return ( localizeWithPath(
            'vs/workbench/services/preferences/browser/keybindingsEditorInput',
            'keybindingsInputName',
            "Keyboard Shortcuts"
        ));
    }
    getIcon() {
        return KeybindingsEditorIcon;
    }
    async resolve() {
        return this.keybindingsModel;
    }
    matches(otherInput) {
        return otherInput instanceof KeybindingsEditorInput_1;
    }
    dispose() {
        this.keybindingsModel.dispose();
        super.dispose();
    }
};
KeybindingsEditorInput = KeybindingsEditorInput_1 = ( __decorate([
    ( __param(0, IInstantiationService))
], KeybindingsEditorInput));
export { KeybindingsEditorInput };

==> monaco-vscode-api-5.1.1.tgz: package/vscode/src/vs/workbench/services/preferences/browser/keybindingsEditorInput.js <==
import { __decorate, __param } from '../../../../../../../external/tslib/tslib.es6.js';
import { Codicon } from '../../../../base/common/codicons.js';
import { OS } from '../../../../base/common/platform.js';
import { localizeWithPath } from '../../../../nls.js';
import { IInstantiationService } from '../../../../platform/instantiation/common/instantiation.js';
import { registerIcon } from '../../../../platform/theme/common/iconRegistry.js';
import { EditorInput } from '../../../common/editor/editorInput.js';
import { KeybindingsEditorModel } from './keybindingsEditorModel.js';
var KeybindingsEditorInput_1;
const _moduleId = "vs/workbench/services/preferences/browser/keybindingsEditorInput";
const KeybindingsEditorIcon = registerIcon('keybindings-editor-label-icon', Codicon.keyboard, ( localizeWithPath(_moduleId, 0, 'Icon of the keybindings editor label.')));
let KeybindingsEditorInput = class KeybindingsEditorInput extends EditorInput {
    static { KeybindingsEditorInput_1 = this; }
    static { this.ID = 'workbench.input.keybindings'; }
    constructor(instantiationService) {
        super();
        this.searchOptions = null;
        this.resource = undefined;
        this.keybindingsModel = instantiationService.createInstance(KeybindingsEditorModel, OS);
    }
    get typeId() {
        return KeybindingsEditorInput_1.ID;
    }
    getName() {
        return ( localizeWithPath(_moduleId, 1, "Keyboard Shortcuts"));
    }
    getIcon() {
        return KeybindingsEditorIcon;
    }
    async resolve() {
        return this.keybindingsModel;
    }
    matches(otherInput) {
        return otherInput instanceof KeybindingsEditorInput_1;
    }
    dispose() {
        this.keybindingsModel.dispose();
        super.dispose();
    }
};
KeybindingsEditorInput = KeybindingsEditorInput_1 = ( (__decorate([
    ( (__param(0, IInstantiationService)))
], KeybindingsEditorInput)));
export { KeybindingsEditorInput };
